import jwt, { Algorithm } from 'jsonwebtoken';
import { getDefaultPath } from './osutils';
import dotenv from 'dotenv';

// Cargar las variables de entorno desde el archivo .env
dotenv.config({ path: getDefaultPath('global') + '/.env' });

const apiKey = process.env.API_KEY;
const tokenAlgorithm = process.env.TOKEN_ALGORITHM as Algorithm;    

export const createJWT = (id: string, subject: object, ...time: number[]): string => {
  return createToken(id, "oliverpqh@gmail.com", subject, ...time);
}


export const createToken = (id: string, issuer: string, subject: object, ...time: number[]) => {
    const ttlMillis = time[0] || Number(process.env.VIGENCIA_TOKEN) || 3600000; // Default to 1 hour
    const now = Date.now();
    if (!apiKey) {
        throw new Error('API_KEY is required but not defined in environment variables.');
    }
    const signingKey = Buffer.from(apiKey, 'base64');

    // JWT payload
    const payload = {
        id: id,
        issuedAt: Math.floor(now / 1000),
        subject: subject,
        issuer: issuer
    };

    const options = {
        algorithm: tokenAlgorithm,
        expiresIn: ttlMillis >= 0 ? Math.floor((now + ttlMillis) / 1000) : undefined
    };

    // Create and sign the JWT
    const token = jwt.sign(payload, signingKey, options);
    return token;
};


export const parseJWT = (token: string, ...id: string[]) => {
    try {
        // Ensure apiKey is defined
        if (!apiKey) {
            throw new Error('API_KEY is required but not defined in environment variables.');
        }

        const decoded = jwt.verify(token, Buffer.from(apiKey, 'base64'), {
            algorithms: [tokenAlgorithm]
        });
        return decoded;
    } catch (err) {
        throw err;
    }
};


